@@ -167,9 +167,9 @@ class Executor():
         'system':  platform.system(),
         'version':  platform.version(),
         'uname':  platform.uname(),
-        'gpu_name': gpu_name,
-        'gpu_free_memory': gpu_free_memory,
-        'gpu_load': gpu_load,
+        'gpu_name': gpu_name if gpu_name else None,
+        'gpu_free_memory': gpu_free_memory if gpu_free_memory else None,
+        'gpu_load': gpu_load if gpu_load else None,
       },
       # tags are a way of defining features for tests to select where to run on
       # i.e. a test can say it wants to run on: ['windows', 'amd', 'max spec']
